pub trait ToBoxworks {
type Output;
// Required method
fn to_boxworks(&self) -> Self::Output;
}Expand description
Convert a Box language data structure to a Boxworks data structure.
pub trait ToBoxworks {
type Output;
// Required method
fn to_boxworks(&self) -> Self::Output;
}Convert a Box language data structure to a Boxworks data structure.