Explanation

Struct Explanation 

pub struct Explanation {
    pub lower_cased: String,
    pub patterns: Vec<MatchedPattern>,
    pub aggregate_scores: Vec<u8>,
}
Explanation of why a word is hyphenated the way it is.

Fields

lower_cased: String

Lower cased word.

patterns: Vec<MatchedPattern>

All patterns that matched the word.

aggregate_scores: Vec<u8>

Aggregate scores among all scores for matching patterns.

Implementations

Source

impl Explanation

pub fn is_interesting(&self) -> bool

Whether this hyphenation explanation is “interesting”

A hyphenation is interesting if there is at least one hyphen and there is at least one position where there are competing patterns (i.e. one pattern says to hyphenate and another says not to).