FontRepo

Trait FontRepo 

pub trait FontRepo {
    type Format: FontFormat;

    // Required method
    fn add_font(&mut self, id: Font, font: Self::Format);
}
A font repository is where font data is stored.

We currently envisage that typesetting engines will contain a font repo that they will use for getting font metric data.

Required Associated Types

type Format: FontFormat

Format of files that are store in this repo

Required Methods

fn add_font(&mut self, id: Font, font: Self::Format)

Implementors

Source

impl<T: FontFormat> FontRepo for NoOpFontRepo<T>