LcCodeComponent

Type Alias LcCodeComponent 

pub type LcCodeComponent = Component<u8, 256, LcCodeMarker>;
Component that holds the 256 \lccode values.

Each entry is the lowercase character code for the corresponding character (0–255). Although the values are semantically character codes (0–255), the storage type is i32 because that is the integer type supported by the Texlang variable system.

Aliased Type

pub struct LcCodeComponent(/* private fields */);