pub struct Ligature {
pub char: char,
pub font: FontId,
pub original_chars: Rc<str>,
pub includes_left_boundary: bool,
pub includes_right_boundary: bool,
}Expand description
A ligature.
Described in TeX.2021.143.
Fields
char: charfont: FontIdoriginal_chars: Rc<str>The original characters that were replaced by the ligature. This is used if the engine needs to break apart the ligature in order to perform hyphenation.
While most ligatures come from 2 characters (e.g. ff), TeX’s lig/kern programming language allows for a single ligature to come from arbitrarily many characters.
includes_left_boundary: boolincludes_right_boundary: boolImplementations
Sourceimpl Ligature
impl Ligature
Sourcepub fn standardize_lossy(&mut self)
pub fn standardize_lossy(&mut self)
Puts the ligature into a lossy standard form.
What follows is the motivation for this method.
TeX supports logging its internal typesetting data structures. All of these data structures are reimplemented in this module, and can be reconstructed from TeX’s log output using the Boxworks TeX log parsing logic. This system used throughout Boxworks to verify that Boxworks’s typesetting code gives the identical results to TeX’s.
Unfortunately, however, TeX’s display logic for ligatures specifically is lossy. In the TeX’s logging format the line
..\tenrm a (ligature |)can mean one of three things:
- a ligature ‘a’ that replaces the character
|, - a ligature ‘a’ that replaces the left boundary, or
- a ligature ‘a’ that replaces the right boundary.
This means that it’s not possible to reconstruct fully the internal ligature data structure from the logging output. Boxworks TeX log parsing logic assumes the first interpretation holds: the log line is parsed into the following value:
Ligature {
char: 'a',
font: common::FontId::ONE,
original_chars: "|".into(),
includes_left_boundary: false,
includes_right_boundary: false,
};This specifically presents issues when we want to verify TeX’s output with Boxworks where the correct value is, say,
Ligature {
char: 'a',
font: common::FontId::ONE,
original_chars: "".into(),
includes_left_boundary: false,
includes_right_boundary: true,
};A unit test that compares these outputs will fail.
This method is designed to help write unit tests that pass. It standardizes the ligature into the from parse from TeX. We can then compare the standardized form with TeX’s output. This does mean that such unit tests can’t verify which form is the right one.