TexEngine

Trait TexEngine 

pub trait TexEngine {
    // Required method
    fn run(
        &mut self,
        tex_source_code: &str,
        auxiliary_files: &HashMap<PathBuf, Vec<u8>>,
    ) -> String;
}
Implementations of this trait can run TeX source code and return stdout.

Required Methods

fn run( &mut self, tex_source_code: &str, auxiliary_files: &HashMap<PathBuf, Vec<u8>>, ) -> String

Run the provided TeX source code and return stdout.

The method accepts a mutable reference to that implementations of this trait can assume there are not concurrent runs of the engine. This is useful for real TeX engines which need to write files to disk.

Implementors