diagnostic_preamble

Function diagnostic_preamble 

pub fn diagnostic_preamble(font_file_stem: &str) -> String
Returns the TeX preamble to use when comparing Boxworks output to TeX’s.

The preamble enables \tracingparagraphs, works around diagnostics that Boxworks does not implement yet, and activates the font whose metrics file (e.g. cmr10.tfm for a font_file_stem of cmr10) must be provided as an auxiliary file when the engine runs.