Whatsit

Trait Whatsit 

pub trait Whatsit: Debug {
    // Provided method
    fn hyphenation_hook(&self) { ... }
}
A whatsit node

This is used to facilitate extensions to TeX. It’s unclear right now how what the API of it will be, though it can be figured out by reading the Chapter 53 Extensions of TeX.

Knuth uses this node type to implement both \write and \special so we’ll eventually find out.

Described in TeX.2021.146.

Provided Methods

Implementors