pub struct Rule {
pub height: Scaled,
pub width: Scaled,
pub depth: Scaled,
}Expand description
A rule stands for a solid black rectangle.
It has width, depth and height fields. However if any of these dimensions is -2^30, the actual value will be determined by running rule up to the boundary of the innermost, enclosing box. This is called a “running dimension”. The width is never running in an hlist; the height and depth are never running in a vlist.
Described in TeX.2021.138.
Fields
height: Scaledwidth: Scaleddepth: ScaledImplementations