pub enum Horizontal {
}Expand description
Element of a horizontal list.
Variants
Char(Char)
HBox(HBox)
VBox(VBox)
Rule(Rule)
Mark(Mark)
Insertion(Insertion)
Adjust(Adjust)
Ligature(Ligature)
Discretionary(Discretionary)
Whatsit(Rc<dyn Whatsit>)
Math(Math)
Glue(Glue)
Kern(Kern)
Penalty(Penalty)
Implementations
Sourceimpl Horizontal
impl Horizontal
Sourcepub fn precedes_break(&self) -> bool
pub fn precedes_break(&self) -> bool
Whether a glue node that comes after this node may be broken.
For char nodes, this function is essentially undefined in Knuth’s
TeX. More specifically, the value depends on the exact character code.
In TeX this function is never called for char nodes which is why this
is not a problem. Here, we return true for char nodes based on
my analysis of all places in Knuth’s TeX where it is invoked:
-
TeX.2021.868:
precedes_breakis called on variablecur_pwhich is a pointer to a horizontal list. Before this call, the calling code first checks if the node is a character and if so follows the same code path. Thus returningtruehere is the right thing to do. -
TeX.2021.973: the function is called on a variable
prev_pwhich is a pointer to a vertical list and so the char case never arises. -
TeX.2021.1000: same as the last case.
This function is defined in TeX.2021.148.
Sourcepub fn non_discardable(&self) -> bool
pub fn non_discardable(&self) -> bool
Whether this node is discarded after a break.
As with Self::precedes_break, this function is essentially undefined for char nodes in Knuth’s TeX. However there is only one call site (TeX.2021.879) and in that call site char nodes behave as if this function returns true.
This function is defined in TeX.2021.148.