pub struct Discretionary {
pub pre_break: Vec<DiscretionaryElem>,
pub post_break: Vec<DiscretionaryElem>,
pub replace_count: u32,
}Expand description
A discretionary break.
Described in TeX.2021.145.
Fields
pre_break: Vec<DiscretionaryElem>Material to insert before this node, if the break occurs here.
post_break: Vec<DiscretionaryElem>Material to insert after this node, if the break occurs here.
replace_count: u32Number of subsequent nodes to skip if the break occurs here.
Implementations
Sourceimpl Discretionary
impl Discretionary