pub struct Insertion {
pub box_number: u8,
pub height: Scaled,
pub split_max_depth: Scaled,
pub split_top_skip: Glue,
pub float_penalty: u32,
pub vbox: Vec<Vertical>,
}Expand description
Vertical material to be inserted.
This node is related to the TeX primitive \insert.
Described in TeX.2021.140.
Fields
box_number: u8height: ScaledSlightly misnamed: it actually holds the natural height plus depth of the vertical list being inserted.
split_max_depth: ScaledUsed in case this insertion is split.
split_top_skip: Gluefloat_penalty: u32Penalty to be used if this insertion floats to a subsequent page after a split insertion of the same class.
vbox: Vec<Vertical>Trait Implementations
Sourceimpl From<Insertion> for Horizontal
impl From<Insertion> for Horizontal
impl StructuralPartialEq for Insertion