pub struct GlueRatio {
pub num: Scaled,
pub den: Scaled,
}Expand description
Ratio by which glue should shrink or stretch.
This is one of the few (only?) places in Knuth’s TeX where a floating point number is used. In general TeX uses fixed point integers to ensure that the results are the same on every computer/CPU. But the exact semantics of the glue ratio don’t affect the output, so using a float is deemed okay by Knuth.
However we opt to use a real ratio: i.e., a numerator and a denominator.
Described in TeX.2021.109.
Fields
num: Scaledden: ScaledImplementations