pub enum PackWidth {
Exact(Scaled),
Additional(Scaled),
}Expand description
Pack width specifies how width is handled when packing
Variants
Exact(Scaled)
Make the box exactly this width, generally by stretching or shrinking glue within the box.
Additional(Scaled)
Make the box its natural width, plus the additional width specified here.