pub trait ToBoxLang {
type Output;
// Required method
fn to_box_lang(&self) -> Self::Output;
}Expand description
Convert a Boxworks data structure to a Box language data structure.
pub trait ToBoxLang {
type Output;
// Required method
fn to_box_lang(&self) -> Self::Output;
}Convert a Boxworks data structure to a Box language data structure.