get_adjdemerits

Function get_adjdemerits 

pub fn get_adjdemerits<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \adjdemerits command.

This is a command for a singleton variable of type i32. It requires that the state contain the component Component.