get_pretolerance

Function get_pretolerance 

pub fn get_pretolerance<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \pretolerance command.

This is a command for a singleton variable of type i32. It requires that the state contain the component Component.