get_parfillskip

Function get_parfillskip 

pub fn get_parfillskip<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \parfillskip command.

This is a command for a singleton variable of type [common::Glue]. It requires that the state contain the component Component.