get_rightskip

Function get_rightskip 

pub fn get_rightskip<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \rightskip command.

This is a command for a singleton variable of type [common::Glue]. It requires that the state contain the component Component.