get_leftskip

Function get_leftskip 

pub fn get_leftskip<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \leftskip command.

This is a command for a singleton variable of type [common::Glue]. It requires that the state contain the component Component.