get_linepenalty

Function get_linepenalty 

pub fn get_linepenalty<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \linepenalty command.

This is a command for a singleton variable of type i32. It requires that the state contain the component Component.