get_looseness

Function get_looseness 

pub fn get_looseness<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \looseness command.

This is a command for a singleton variable of type i32. It requires that the state contain the component Component.