get_tolerance

Function get_tolerance 

pub fn get_tolerance<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \tolerance command.

This is a command for a singleton variable of type i32. It requires that the state contain the component Component.