Function get_hyphenpenalty
Source pub fn get_hyphenpenalty<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \hyphenpenalty command.
This is a command for a singleton variable of type i32. It requires that the state contain the component Component.