Function get_doublehyphendemerits
Source pub fn get_doublehyphendemerits<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \doublehyphendemerits command.
This is a command for a singleton variable of type i32. It requires that the state contain the component Component.