Function get_finalhyphendemerits
Source pub fn get_finalhyphendemerits<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \finalhyphendemerits command.
This is a command for a singleton variable of type i32. It requires that the state contain the component Component.