Function get_exhyphenpenalty
Source pub fn get_exhyphenpenalty<S: HasComponent<Component>>() -> BuiltIn<S>
Get the \exhyphenpenalty command.
This is a command for a singleton variable of type i32. It requires that the state contain the component Component.