Hyphenator

Struct Hyphenator 

pub struct Hyphenator { /* private fields */ }
Hyphenates words using TeX’s pattern-matching algorithm (Knuth-Liang).

Construct with Hyphenator::plain_tex_en_us for the standard plain TeX English patterns, or load custom patterns with Hyphenator::load_patterns.

Implementations

Source

impl Hyphenator

pub fn plain_tex_en_us() -> Self

Construct a hyphenator loaded with plain TeX’s English (US) patterns and exceptions.

pub fn load_patterns(&mut self, patterns: &str)

Load hyphenation patterns from a whitespace-separated string in TeX pattern format.

pub fn insert_exceptions(&mut self, hyphenated_words: &str)

Add multiple hyphenation exceptions. These are separate words separated by whitespace, with each word satisfying the format in Self::insert_exception.

pub fn insert_exception(&mut self, hyphenated_word: &str)

Add a hyphenation exception. The word is given with hyphens marking the allowed break points, e.g. "hy-phen-ation".

pub fn hypthenate<L: LowerCaser>( &self, lower_caser: &L, word: &str, target: &mut String, )

Hyphenate a word, returning it with - inserted at each valid break point.

pub fn calculate_indices<L: LowerCaser>( &self, lower_caser: &L, word: &str, ) -> impl Iterator<Item = usize>

Return the set of character indices before which a hyphen may be inserted.