AsciiLowerCaser

Struct AsciiLowerCaser 

pub struct AsciiLowerCaser {}
The ASCII implementation of LowerCaser returns the lower case letter for all ASCII alphabetic characters, and None for all other characters.