pub trait LowerCaser {
// Required method
fn to_lower_case(&self, c: char) -> Option<char>;
}Expand description
Implementations of this trait can get the lower case character of a character.
pub trait LowerCaser {
// Required method
fn to_lower_case(&self, c: char) -> Option<char>;
}Implementations of this trait can get the lower case character of a character.