pub fn finish_parsing_balanced_tokens<S: TokenStream>(
stream: &mut S,
result: &mut Vec<Token>,
) -> Result<()>Expand description
Parses balanced tokens from the stream.
This function assumes the the initial opening brace has ready been consumed. It returns false if the input ends before balanced tokens completed.
This function is somewhat analogous to scan_toks in Knuthâs TeX.
For us the xpand parameter can be controlled by providing a different token stream.