pub trait FontRepo {
type Format: FontFormat;
// Required method
fn add_font(&mut self, id: Font, font: Self::Format);
}Expand description
A font repository is where font data is stored.
We currently envisage that typesetting engines will contain a font repo that they will use for getting font metric data.