pub fn get_expandafter_simple<S: TexlangState>() -> BuiltIn<S>Expand description
Get the simple \expandafter command.
This is the simplest implementation of the command, and the same implementation as in the original TeX.
pub fn get_expandafter_simple<S: TexlangState>() -> BuiltIn<S>Get the simple \expandafter command.
This is the simplest implementation of the command, and the same implementation as in the original TeX.